@@ -12,9 +12,13 @@ from chip.clusters.ClusterObjects import (
     ClusterObjectDescriptor,
     ClusterObjectFieldDescriptor,
 )
+from chip.clusters.Objects import BasicInformation, ElectricalPowerMeasurement
 from chip.tlv import float32, uint
 
-from matter_server.common.helpers.util import parse_attribute_path
+from matter_server.common.helpers.util import (
+    create_attribute_path_from_attribute,
+    parse_attribute_path,
+)
 
 if TYPE_CHECKING:
     from matter_server.common.models import MatterNodeData
@@ -27,13 +31,19 @@ if TYPE_CHECKING:
 ALL_CUSTOM_CLUSTERS: dict[int, Cluster] = {}
 ALL_CUSTOM_ATTRIBUTES: dict[int, dict[int, ClusterAttributeDescriptor]] = {}
 
+VENDOR_ID_EVE = 4874
+
 
 @dataclass
 class CustomClusterMixin:
     """Base model for a vendor specific custom cluster."""
 
     id: ClassVar[int]  # cluster id
-    should_poll: bool = False  # should the entire cluster be polled for state changes?
+
+    @staticmethod
+    def should_poll(node_data: MatterNodeData) -> bool:  # noqa: ARG004
+        """Check if the (entire) custom cluster should be polled for state changes."""
+        return False
 
     def __init_subclass__(cls: Cluster, *args, **kwargs) -> None:
         """Register a subclass."""
@@ -45,7 +55,10 @@ class CustomClusterMixin:
 class CustomClusterAttributeMixin:
     """Base model for a vendor specific custom cluster attribute."""
 
-    should_poll: bool = False  # should this attribute be polled ?
+    @staticmethod
+    def should_poll(node_data: MatterNodeData) -> bool:  # noqa: ARG004
+        """Check if the custom attribute should be polled for state changes."""
+        return False
 
     def __init_subclass__(cls: ClusterAttributeDescriptor, *args, **kwargs) -> None:
         """Register a subclass."""
@@ -55,6 +68,23 @@ class CustomClusterAttributeMixin:
         ALL_CUSTOM_ATTRIBUTES[cls.cluster_id][cls.attribute_id] = cls
 
 
+def should_poll_eve_energy(node_data: MatterNodeData) -> bool:
+    """Check if the (Eve Energy) custom attribute should be polled for state changes."""
+    attr_path = create_attribute_path_from_attribute(
+        0, BasicInformation.Attributes.VendorID
+    )
+    if node_data.attributes.get(attr_path) != VENDOR_ID_EVE:
+        # Some implementation (such as MatterBridge) use the
+        # Eve cluster to send the power measurements. Filter that out.
+        return False
+    # if the ElectricalPowerMeasurement cluster is NOT present,
+    # we should poll the custom Eve cluster attribute(s).
+    attr_path = create_attribute_path_from_attribute(
+        2, ElectricalPowerMeasurement.Attributes.AttributeList
+    )
+    return node_data.attributes.get(attr_path) is None
+
+
 @dataclass
 class EveCluster(Cluster, CustomClusterMixin):
     """Custom (vendor-specific) cluster for Eve - Vendor ID 4874 (0x130a)."""
@@ -90,6 +120,12 @@ class EveCluster(Cluster, CustomClusterMixin):
                 ClusterObjectFieldDescriptor(
                     Label="pressure", Tag=0x130A0014, Type=float32
                 ),
+                ClusterObjectFieldDescriptor(
+                    Label="valvePosition", Tag=0x130A0018, Type=int
+                ),
+                ClusterObjectFieldDescriptor(
+                    Label="motionSensitivity", Tag=0x130A000D, Type=int
+                ),
             ]
         )
 
@@ -101,6 +137,8 @@ class EveCluster(Cluster, CustomClusterMixin):
     current: float32 | None = None
     altitude: float32 | None = None
     pressure: float32 | None = None
+    valvePosition: int | None = None
+    motionSensitivity: int | None = None
 
     class Attributes:
         """Attributes for the Eve Cluster."""
@@ -109,8 +147,6 @@ class EveCluster(Cluster, CustomClusterMixin):
         class TimesOpened(ClusterAttributeDescriptor, CustomClusterAttributeMixin):
             """TimesOpened Attribute within the Eve Cluster."""
 
-            should_poll = True
-
             @ChipUtility.classproperty
             def cluster_id(cls) -> int:
                 """Return cluster id."""
@@ -132,7 +168,7 @@ class EveCluster(Cluster, CustomClusterMixin):
         class Watt(ClusterAttributeDescriptor, CustomClusterAttributeMixin):
             """Watt Attribute within the Eve Cluster."""
 
-            should_poll = True
+            should_poll = should_poll_eve_energy
 
             @ChipUtility.classproperty
             def cluster_id(cls) -> int:
@@ -155,7 +191,7 @@ class EveCluster(Cluster, CustomClusterMixin):
         class WattAccumulated(ClusterAttributeDescriptor, CustomClusterAttributeMixin):
             """WattAccumulated Attribute within the Eve Cluster."""
 
-            should_poll = True
+            should_poll = should_poll_eve_energy
 
             @ChipUtility.classproperty
             def cluster_id(cls) -> int:
@@ -180,7 +216,7 @@ class EveCluster(Cluster, CustomClusterMixin):
         ):
             """wattAccumulatedControlPoint Attribute within the Eve Cluster."""
 
-            should_poll = True
+            should_poll = should_poll_eve_energy
 
             @ChipUtility.classproperty
             def cluster_id(cls) -> int:
@@ -203,7 +239,7 @@ class EveCluster(Cluster, CustomClusterMixin):
         class Voltage(ClusterAttributeDescriptor, CustomClusterAttributeMixin):
             """Voltage Attribute within the Eve Cluster."""
 
-            should_poll = True
+            should_poll = should_poll_eve_energy
 
             @ChipUtility.classproperty
             def cluster_id(cls) -> int:
@@ -226,7 +262,7 @@ class EveCluster(Cluster, CustomClusterMixin):
         class Current(ClusterAttributeDescriptor, CustomClusterAttributeMixin):
             """Current Attribute within the Eve Cluster."""
 
-            should_poll = True
+            should_poll = should_poll_eve_energy
 
             @ChipUtility.classproperty
             def cluster_id(cls) -> int:
@@ -287,6 +323,50 @@ class EveCluster(Cluster, CustomClusterMixin):
 
             value: float32 = 0
 
+        @dataclass
+        class ValvePosition(ClusterAttributeDescriptor, CustomClusterAttributeMixin):
+            """ValvePosition Attribute within the Eve Cluster."""
+
+            @ChipUtility.classproperty
+            def cluster_id(cls) -> int:
+                """Return cluster id."""
+                return 0x130AFC01
+
+            @ChipUtility.classproperty
+            def attribute_id(cls) -> int:
+                """Return attribute id."""
+                return 0x130A0018
+
+            @ChipUtility.classproperty
+            def attribute_type(cls) -> ClusterObjectFieldDescriptor:
+                """Return attribute type."""
+                return ClusterObjectFieldDescriptor(Type=int)
+
+            value: int = 0
+
+        @dataclass
+        class MotionSensitivity(
+            ClusterAttributeDescriptor, CustomClusterAttributeMixin
+        ):
+            """MotionSensitivity Attribute within the Eve Cluster."""
+
+            @ChipUtility.classproperty
+            def cluster_id(cls) -> int:
+                """Return cluster id."""
+                return 0x130AFC01
+
+            @ChipUtility.classproperty
+            def attribute_id(cls) -> int:
+                """Return attribute id."""
+                return 0x130A000D
+
+            @ChipUtility.classproperty
+            def attribute_type(cls) -> ClusterObjectFieldDescriptor:
+                """Return attribute type."""
+                return ClusterObjectFieldDescriptor(Type=int)
+
+            value: int = 0
+
 
 @dataclass
 class NeoCluster(Cluster, CustomClusterMixin):
@@ -502,12 +582,12 @@ def check_polled_attributes(node_data: MatterNodeData) -> set[str]:
         endpoint_id, cluster_id, attribute_id = parse_attribute_path(attr_path)
         if not (custom_cluster := ALL_CUSTOM_CLUSTERS.get(cluster_id)):
             continue
-        if custom_cluster.should_poll:
+        if custom_cluster.should_poll(node_data):
             # the entire cluster needs to be polled
             attributes_to_poll.add(f"{endpoint_id}/{cluster_id}/*")
             continue
         custom_attribute = ALL_CUSTOM_ATTRIBUTES[cluster_id].get(attribute_id)
-        if custom_attribute and custom_attribute.should_poll:
+        if custom_attribute and custom_attribute.should_poll(node_data):
             # this attribute needs to be polled
             attributes_to_poll.add(attr_path)
     return attributes_to_poll
